from sqlmodel import Session
from backend.models.models import (
    User,
    Shop,
    Category,
    Product,
    ProductImage,
    Order,
    OrderItem,
)
from backend.utils.hashing import hash_password


def insert_dummy_data(session: Session):
    if not session.query(User).first():
        users = [
            User(
                username="string",
                email="user@example.com",
                password=hash_password("string"),
                role="customer",
            ),
            User(
                username="shop_owner",
                email="owner@example.com",
                password=hash_password("string"),
                role="shop_owner",
            ),
        ]
        session.add_all(users)
        session.commit()

    if not session.query(Shop).first():
        shops = [
            Shop(
                owner_id=2,
                name="Google HQ",
                description="Google Headquarters",
                image_url="app/static/default/default_shop.png",
                address="1600 Amphitheatre Parkway, Mountain View, CA",
                latitude=37.4220656,
                longitude=-122.0840897,
            ),
            Shop(
                owner_id=2,
                name="Apple HQ",
                description="Apple Headquarters",
                image_url="app/static/default/default_shop.png",
                address="1 Infinite Loop, Cupertino, CA",
                latitude=37.33182,
                longitude=-122.03118,
            ),
            Shop(
                owner_id=2,
                name="Empire State Building",
                description="Famous skyscraper in New York",
                image_url="app/static/default/default_shop.png",
                address="350 Fifth Avenue, New York, NY",
                latitude=40.748817,
                longitude=-73.985428,
            ),
            Shop(
                owner_id=2,
                name="Sherlock's Home",
                description="Fictional detective's residence",
                image_url="app/static/default/default_shop.png",
                address="221B Baker Street, London, UK",
                latitude=51.523767,
                longitude=-0.1585557,
            ),
            Shop(
                owner_id=2,
                name="Eiffel Tower",
                description="Iconic landmark in Paris",
                image_url="app/static/default/default_shop.png",
                address="Eiffel Tower, Paris, France",
                latitude=48.8588443,
                longitude=2.2943506,
            ),
        ]
        session.add_all(shops)
        session.commit()

    if not session.query(Category).first():
        categories = [Category(name=f"Category{i}") for i in range(1, 6)]
        session.add_all(categories)
        session.commit()

    if not session.query(Product).first():
        products = [
            Product(
                shop_id=i,
                category_id=i,
                name=f"Product{i}",
                description=f"Description for Product {i}",
                price=99.99 + i,
                stock=10 * i,
            )
            for i in range(1, 6)
        ]
        session.add_all(products)
        session.commit()

    if not session.query(ProductImage).first():
        images = [
            ProductImage(
                product_id=i, image_url="app/static/default/default_product.png"
            )
            for i in range(1, 6)
        ]
        session.add_all(images)
        session.commit()

    if not session.query(Order).first():
        orders = [
            Order(
                user_id=1,
                shop_id=1,
                total_price=150.0,
                shipping_price=10.0,
                status="pending",
                delivery_address="1600 Amphitheatre Parkway, Mountain View, CA",
                delivery_latitude=37.4220656,
                delivery_longitude=-122.0840897,
            ),
            Order(
                user_id=1,
                shop_id=2,
                total_price=200.0,
                shipping_price=15.0,
                status="shipped",
                delivery_address="1 Infinite Loop, Cupertino, CA",
                delivery_latitude=37.33182,
                delivery_longitude=-122.03118,
            ),
            Order(
                user_id=1,
                shop_id=3,
                total_price=250.0,
                shipping_price=20.0,
                status="delivered",
                delivery_address="350 Fifth Avenue, New York, NY",
                delivery_latitude=40.748817,
                delivery_longitude=-73.985428,
            ),
            Order(
                user_id=1,
                shop_id=4,
                total_price=300.0,
                shipping_price=25.0,
                status="pending",
                delivery_address="221B Baker Street, London, UK",
                delivery_latitude=51.523767,
                delivery_longitude=-0.1585557,
            ),
            Order(
                user_id=1,
                shop_id=5,
                total_price=350.0,
                shipping_price=30.0,
                status="canceled",
                delivery_address="Eiffel Tower, Paris, France",
                delivery_latitude=48.8588443,
                delivery_longitude=2.2943506,
            ),
        ]
        session.add_all(orders)
        session.commit()

    if not session.query(OrderItem).first():
        order_items = [
            OrderItem(order_id=i, product_id=i, quantity=i, price=99.99 + i)
            for i in range(1, 6)
        ]
        session.add_all(order_items)
        session.commit()
